@@ -1,6 +1,6 @@
 import streamlit as st
 from widgets.base.exceptions import ResourceConfigurationException
-from widgets.streamlit.resource import StResource
+from widgets.streamlit.resource.base import StResource
 
 
 class StString(StResource):
